@@ -31,6 +31,7 @@ from django.conf import settings
 from django.contrib.auth.models import Group, User
 from django.http import HttpRequest
 from django.test.client import RequestFactory
+from django.utils.encoding import force_text
 from django.utils.safestring import SafeText
 from django.utils.six.moves import range
 from kgb import SpyAgency
@@ -158,7 +159,8 @@ class DataGridTests(SpyAgency, TestCase):
         response = self.datagrid.render_listview_to_response()
         self.assertEqual(response.status_code, 200)
 
-        content = response.content
+        content = force_text(response.content)
+
         self.assertIn('<div class="datagrid-wrapper" id="datagrid-0">',
                       content)
         self.assertIn('<div class="datagrid-main">', content)
