@@ -10,6 +10,8 @@ from djblets.extensions.errors import (DisablingExtensionError,
                                        EnablingExtensionError,
                                        InvalidExtensionError)
 from djblets.extensions.models import RegisteredExtension
+from djblets.extensions.signals import (extension_initialized,
+                                        extension_uninitialized)
 from djblets.urls.resolvers import DynamicURLResolver
 from djblets.webapi.decorators import (webapi_login_required,
                                        webapi_permission_required,
@@ -19,6 +21,7 @@ from djblets.webapi.errors import (DOES_NOT_EXIST,
                                    ENABLE_EXTENSION_FAILED,
                                    DISABLE_EXTENSION_FAILED,
                                    PERMISSION_DENIED)
+from djblets.webapi.fields import BooleanFieldType, StringFieldType
 from djblets.webapi.resources.base import WebAPIResource
 
 
@@ -27,54 +30,54 @@ class ExtensionResource(WebAPIResource):
     model = RegisteredExtension
     fields = {
         'author': {
-            'type': str,
+            'type': StringFieldType,
             'description': 'The author of the extension.',
         },
         'author_url': {
-            'type': str,
+            'type': StringFieldType,
             'description': "The author's website.",
         },
         'can_disable': {
-            'type': bool,
+            'type': BooleanFieldType,
             'description': 'Whether or not the extension can be disabled.',
         },
         'can_enable': {
-            'type': bool,
+            'type': BooleanFieldType,
             'description': 'Whether or not the extension can be enabled.',
         },
         'class_name': {
-            'type': str,
+            'type': StringFieldType,
             'description': 'The class name for the extension.',
         },
         'enabled': {
-            'type': bool,
+            'type': BooleanFieldType,
             'description': 'Whether or not the extension is enabled.',
         },
         'installed': {
-            'type': bool,
+            'type': BooleanFieldType,
             'description': 'Whether or not the extension is installed.',
         },
         'loadable': {
-            'type': bool,
+            'type': BooleanFieldType,
             'description': 'Whether or not the extension is currently '
                            'loadable. An extension may be installed but '
                            'missing or may be broken due to a bug.',
         },
         'load_error': {
-            'type': str,
+            'type': StringFieldType,
             'description': 'If the extension could not be loaded, this will '
                            'contain any errors captured while trying to load.',
         },
         'name': {
-            'type': str,
+            'type': StringFieldType,
             'description': 'The name of the extension.',
         },
         'summary': {
-            'type': str,
+            'type': StringFieldType,
             'description': "A summary of the extension's functionality.",
         },
         'version': {
-            'type': str,
+            'type': StringFieldType,
             'description': 'The installed version of the extension.',
         },
     }
@@ -200,7 +203,7 @@ class ExtensionResource(WebAPIResource):
     @webapi_request_fields(
         required={
             'enabled': {
-                'type': bool,
+                'type': BooleanFieldType,
                 'description': 'Whether or not to make the extension active.'
             },
         },
@@ -230,7 +233,6 @@ class ExtensionResource(WebAPIResource):
                     'needs_reload': e.needs_reload,
                 }
             except InvalidExtensionError as e:
-                raise
                 return ENABLE_EXTENSION_FAILED.with_message(six.text_type(e))
         else:
             try:
@@ -355,3 +357,80 @@ class ExtensionResource(WebAPIResource):
         has been uninitialized.
         """
         self._unattach_extension_resources(ext_class)
+
+
+class ExtensionRootResourceMixin(object):
+    """Mixin for Root Resources making use of Extension Resources.
+
+    As extensions are able to provide their own API resources, this mixin
+    allows a root resource to generate URI templates for non built-in
+    resources.
+
+    See Also:
+        :py:class:`~djblets.webapi.resources.root.RootResource`
+    """
+
+    def __init__(self, *args, **kwargs):
+        """Initialize the extension resource mixin to listen for changes.
+
+        Args:
+            *args (tuple):
+                Additional positional arguments.
+
+            **kwargs (dict):
+                Additional keyword arguments.
+        """
+        super(ExtensionRootResourceMixin, self).__init__(*args, **kwargs)
+
+        extension_initialized.connect(
+            self._generate_extension_uris_for_template)
+        extension_uninitialized.connect(
+            self._remove_extension_uris_from_template)
+
+    def get_extension_resource(self):
+        """Return the associated extension resource.
+
+        Subclasses using this mixin must implement this method.
+
+        Returns:
+            djblets.extensions.resources.ExtensionResource:
+            The extension resource associated with the root resource.
+        """
+        raise NotImplementedError
+
+    def _generate_extension_uris_for_template(self, ext_class, **kwargs):
+        """Generate URI templates for a newly enabled extension.
+
+        Args:
+            ext_class djblets.extensions.extension.Extension:
+                The extension being added to the URI templates.
+
+            **kwargs (dict):
+                Additional keyword arguments.
+        """
+        ext_resource = self.get_extension_resource()
+
+        for resource in ext_class.resources:
+            partial_href = '%s/%s/' % (ext_class.id, resource.uri_name)
+
+            for entry in self.walk_resources(resource, partial_href):
+                self.register_uri_template(entry.name, entry.list_href,
+                                           ext_resource)
+
+    def _remove_extension_uris_from_template(self, ext_class, **kwargs):
+        """Remove the URI templates of an extension when disabled.
+
+        Args:
+            ext_class djblets.extensions.extension.Extension:
+                The extension being removed from the URI templates.
+
+            **kwargs (dict):
+                Additional keyword arguments.
+        """
+        ext_resource = self.get_extension_resource()
+
+        for resource in ext_class.resources:
+            partial_href = '%s/%s/' % (ext_class.id, resource.uri_name)
+
+            for entry in self.walk_resources(resource, partial_href):
+                self.unregister_uri_template(entry.name, ext_resource)
