@@ -7,27 +7,28 @@ from mock import Mock
 
 from djblets.extensions.extension import Extension
 from djblets.extensions.hooks import ExtensionHook, ExtensionHookPoint
-from djblets.extensions.tests.base import ExtensionTestsMixin
+from djblets.extensions.testing import ExtensionTestCaseMixin
 from djblets.testing.testcases import TestCase
 
 
 @six.add_metaclass(ExtensionHookPoint)
-class TestExtensionHook(ExtensionHook):
+class MyTestExtensionHook(ExtensionHook):
     pass
 
 
-class TestExtension(Extension):
+class MyTestExtension(Extension):
     pass
 
 
-class ExtensionHookPointTest(ExtensionTestsMixin, TestCase):
+class ExtensionHookPointTest(ExtensionTestCaseMixin, TestCase):
     """Unit tests for djblets.extensions.hooks.ExtensionHookPoint."""
 
+    extension_class = MyTestExtension
+
     def setUp(self):
         super(ExtensionHookPointTest, self).setUp()
 
-        self.extension = self.setup_extension(TestExtension)
-        self.extension_hook_class = TestExtensionHook
+        self.extension_hook_class = MyTestExtensionHook
         self.dummy_hook = Mock()
         self.extension_hook_class.add_hook(self.dummy_hook)
 
