@@ -13,60 +13,69 @@ from django.template import Context, Template
 from django.utils.safestring import mark_safe
 from kgb import SpyAgency
 
+from djblets.deprecation import RemovedInDjblets30Warning
 from djblets.extensions.extension import Extension, ExtensionInfo, JSExtension
 from djblets.extensions.hooks import TemplateHook
-from djblets.extensions.tests.base import ExtensionTestsMixin
+from djblets.extensions.manager import ExtensionManager
+from djblets.extensions.testing import ExtensionTestCaseMixin
 from djblets.testing.testcases import TestCase
 from pipeline.conf import settings as pipeline_settings
 
 
-class TestJSExtension(JSExtension):
+class MyTestJSExtension(JSExtension):
     model_class = 'FooNew'
 
     def get_model_data(self, request, **kwargs):
         return {'test': 'new'}
 
 
-class TestJSExtensionDeprecated(JSExtension):
+class MyTestJSExtensionDeprecated(JSExtension):
     model_class = 'FooOld'
 
     def get_model_data(self):
         return {'test': 'old'}
 
 
-class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
+class MyTestExtensionManager(ExtensionManager):
+    should_install_static_media = True
+
+
+class MyTestExtension(Extension):
+    # While normally these would be plain dictionaries, we want to ensure
+    # order for testing, so we'll be doing this a bit differently.
+    css_bundles = OrderedDict()
+    css_bundles['default'] = {
+        'source_filenames': (
+            'css/default-test.css',
+        ),
+    }
+    css_bundles['optional'] = {
+        'source_filenames': (
+            'css/optional-test.css',
+        ),
+        'apply_to': ['foo'],
+    }
+
+    js_bundles = OrderedDict()
+    js_bundles['default'] = {
+        'source_filenames': (
+            'js/default-test.js',
+        ),
+    }
+    js_bundles['optional'] = {
+        'source_filenames': (
+            'js/optional-test.js',
+        ),
+        'apply_to': ['foo'],
+    }
+
+    js_extensions = [MyTestJSExtension, MyTestJSExtensionDeprecated]
+
+
+class TemplateTagTests(SpyAgency, ExtensionTestCaseMixin, TestCase):
     """Tests for djblets.extensions.templatetags."""
 
-    class TestExtension(Extension):
-        # While normally these would be plain dictionaries, we want to ensure
-        # order for testing, so we'll be doing this a bit differently.
-        css_bundles = OrderedDict()
-        css_bundles['default'] = {
-            'source_filenames': (
-                'css/default-test.css',
-            ),
-        }
-        css_bundles['optional'] = {
-            'source_filenames': (
-                'css/optional-test.css',
-            ),
-            'apply_to': ['foo'],
-        }
-
-        js_bundles = OrderedDict()
-        js_bundles['default'] = {
-            'source_filenames': (
-                'js/default-test.js',
-            ),
-        }
-        js_bundles['optional'] = {
-            'source_filenames': (
-                'js/optional-test.js',
-            ),
-            'apply_to': ['foo'],
-        }
-
-        js_extensions = [TestJSExtension, TestJSExtensionDeprecated]
+    default_extension_manager_cls = MyTestExtensionManager
 
     def setUp(self):
         def _has_resource(self, path):
@@ -80,8 +89,6 @@ class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
 
         super(TemplateTagTests, self).setUp()
 
-        self.key = uuid.uuid4()
-
         self.spy_on(ExtensionInfo.has_resource,
                     owner=ExtensionInfo,
                     call_fake=_has_resource)
@@ -89,8 +96,7 @@ class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
                     owner=ExtensionInfo,
                     call_fake=_extract_resource)
 
-        self.extension = self.setup_extension(self.TestExtension,
-                                              manager_key=self.key)
+        self.extension = self.setup_extension(MyTestExtension)
         self.request = HttpRequest()
 
         self._old_pipeline_enabled = pipeline_settings.PIPELINE_ENABLED
@@ -139,7 +145,7 @@ class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
                 'ext': self.extension,
                 'request': self.request,
             })),
-            '/ext/djblets.extensions.tests.test_templatetags.TestExtension/'
+            '/ext/djblets.extensions.tests.test_templatetags.MyTestExtension/'
             'css/default-test.dad0c9b31e59.css')
 
     def test_ext_css_bundle_tag_with_pipeline_enabled(self):
@@ -155,7 +161,7 @@ class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
                 'request': self.request,
             })),
             '<link href="/ext/djblets.extensions.tests.test_templatetags'
-            '.TestExtension/css/default.min.dad0c9b31e59.css" '
+            '.MyTestExtension/css/default.min.dad0c9b31e59.css" '
             'rel="stylesheet" type="text/css" />')
 
     def test_ext_css_bundle_tag_with_pipeline_disabled(self):
@@ -171,7 +177,7 @@ class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
                 'request': self.request,
             })),
             '<link href="/ext/djblets.extensions.tests.test_templatetags.'
-            'TestExtension/css/default-test.dad0c9b31e59.css" '
+            'MyTestExtension/css/default-test.dad0c9b31e59.css" '
             'rel="stylesheet" type="text/css" />')
 
     def test_ext_js_bundle_tag_with_pipeline_enabled(self):
@@ -188,7 +194,7 @@ class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
             })),
             '<script type="text/javascript" '
             'src="/ext/djblets.extensions.tests.test_templatetag'
-            's.TestExtension/js/default.min.dad0c9b31e59.js" '
+            's.MyTestExtension/js/default.min.dad0c9b31e59.js" '
             'charset="utf-8"></script>')
 
     def test_ext_js_bundle_tag_with_pipeline_disabled(self):
@@ -205,7 +211,7 @@ class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
             })),
             '<script type="text/javascript" '
             'src="/ext/djblets.extensions.tests.test_templatetag'
-            's.TestExtension/js/default-test.dad0c9b31e59.js" '
+            's.MyTestExtension/js/default-test.dad0c9b31e59.js" '
             'charset="utf-8"></script>')
 
     def test_load_extensions_css_tag_with_pipline_enabled(self):
@@ -221,14 +227,14 @@ class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
         self.assertHTMLEqual(
             t.render(Context({
                 'ext': self.extension,
-                'manager_id': self.key,
+                'manager_id': self.extension_mgr.key,
                 'request': self.request,
             })),
             '<link href="/ext/djblets.extensions.tests.test_templatetags'
-            '.TestExtension/css/default.min.dad0c9b31e59.css" '
+            '.MyTestExtension/css/default.min.dad0c9b31e59.css" '
             'rel="stylesheet" type="text/css" />'
             '<link href="/ext/djblets.extensions.tests.test_templatetags'
-            '.TestExtension/css/optional.min.dad0c9b31e59.css" '
+            '.MyTestExtension/css/optional.min.dad0c9b31e59.css" '
             'rel="stylesheet" type="text/css" />')
 
     def test_load_extensions_css_tag_with_pipline_disabled(self):
@@ -244,14 +250,14 @@ class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
         self.assertHTMLEqual(
             t.render(Context({
                 'ext': self.extension,
-                'manager_id': self.key,
+                'manager_id': self.extension_mgr.key,
                 'request': self.request,
             })),
             '<link href="/ext/djblets.extensions.tests.test_templatetags'
-            '.TestExtension/css/default-test.dad0c9b31e59.css" '
+            '.MyTestExtension/css/default-test.dad0c9b31e59.css" '
             'rel="stylesheet" type="text/css" />'
             '<link href="/ext/djblets.extensions.tests.test_templatetags'
-            '.TestExtension/css/optional-test.dad0c9b31e59.css" '
+            '.MyTestExtension/css/optional-test.dad0c9b31e59.css" '
             'rel="stylesheet" type="text/css" />')
 
     def test_load_extensions_js_tag_with_pipeline_enabled(self):
@@ -267,16 +273,16 @@ class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
         self.assertHTMLEqual(
             t.render(Context({
                 'ext': self.extension,
-                'manager_id': self.key,
+                'manager_id': self.extension_mgr.key,
                 'request': self.request,
             })),
             '<script type="text/javascript" '
             'src="/ext/djblets.extensions.tests.test_templatetags'
-            '.TestExtension/js/default.min.dad0c9b31e59.js" '
+            '.MyTestExtension/js/default.min.dad0c9b31e59.js" '
             'charset="utf-8"></script>'
             '<script type="text/javascript" '
             'src="/ext/djblets.extensions.tests.test_templatetags'
-            '.TestExtension/js/optional.min.dad0c9b31e59.js" '
+            '.MyTestExtension/js/optional.min.dad0c9b31e59.js" '
             'charset="utf-8"></script>')
 
     def test_load_extensions_js_tag_with_pipeline_disabled(self):
@@ -292,16 +298,16 @@ class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
         self.assertHTMLEqual(
             t.render(Context({
                 'ext': self.extension,
-                'manager_id': self.key,
+                'manager_id': self.extension_mgr.key,
                 'request': self.request,
             })),
             '<script type="text/javascript" '
             'src="/ext/djblets.extensions.tests.test_templatetags'
-            '.TestExtension/js/default-test.dad0c9b31e59.js" '
+            '.MyTestExtension/js/default-test.dad0c9b31e59.js" '
             'charset="utf-8"></script>'
             '<script type="text/javascript" '
             'src="/ext/djblets.extensions.tests.test_templatetags'
-            '.TestExtension/js/optional-test.dad0c9b31e59.js" '
+            '.MyTestExtension/js/optional-test.dad0c9b31e59.js" '
             'charset="utf-8"></script>')
 
     def test_init_js_extensions(self):
@@ -311,11 +317,18 @@ class TemplateTagTests(SpyAgency, ExtensionTestsMixin, TestCase):
 
         self.request.resolver_match = ResolverMatch(None, None, None, 'foo')
 
-        content = t.render(Context({
-            'ext': self.extension,
-            'manager_id': self.key,
-            'request': self.request,
-        }))
+        # This warning checks for MyTestJSExtensionDeprecated.get_model_data.
+        expected_message = (
+            'MyTestJSExtensionDeprecated.get_model_data will need to take '
+            'keyword arguments. The old function signature is deprecated.'
+        )
+
+        with self.assertWarns(RemovedInDjblets30Warning, expected_message):
+            content = t.render(Context({
+                'ext': self.extension,
+                'manager_id': self.extension_mgr.key,
+                'request': self.request,
+            }))
 
         self.assertIsNotNone(re.search(
             r'new FooNew\({\s+"test": "new",',
