@@ -94,13 +94,6 @@ function parseArgs() {
                     });
                 break;
 
-            case 'no-color':
-            case 'source-map':
-            case 'autoprefix':
-            case 'js':
-                // These don't matter for the imports check. No-op.
-                break;
-
             default:
                 /* Ignore everything else. */
                 break;
