@@ -9,6 +9,7 @@ from django.http import HttpResponseNotModified
 from django.test.client import RequestFactory
 from django.utils import six
 
+from djblets.deprecation import RemovedInDjblets30Warning
 from djblets.testing.testcases import TestCase, TestModelsLoaderMixin
 from djblets.util.http import encode_etag
 from djblets.webapi.fields import (ResourceFieldType,
@@ -21,7 +22,7 @@ from djblets.webapi.resources.registry import (register_resource_for_model,
 from djblets.webapi.responses import WebAPIResponse
 
 
-class TestGroup(models.Model):
+class MyTestGroup(models.Model):
     name = models.CharField(max_length=10)
     users = models.ManyToManyField(User)
 
@@ -30,7 +31,7 @@ class BaseTestWebAPIResource(WebAPIResource):
     mimetype_vendor = 'djblets-test'
 
 
-class TestUserResource(BaseTestWebAPIResource):
+class MyTestUserResource(BaseTestWebAPIResource):
     name = 'user'
     model = User
     uri_object_key = 'pk'
@@ -51,9 +52,9 @@ class TestUserResource(BaseTestWebAPIResource):
         return 'http://testserver/api/test/users/%s/' % obj.pk
 
 
-class TestGroupResource(BaseTestWebAPIResource):
+class MyTestGroupResource(BaseTestWebAPIResource):
     name = 'group'
-    model = TestGroup
+    model = MyTestGroup
     uri_object_key = 'pk'
 
     fields = {
@@ -70,7 +71,7 @@ class TestGroupResource(BaseTestWebAPIResource):
 
     def get_serializer_for_object(self, o):
         if isinstance(o, User):
-            return TestUserResource()
+            return MyTestUserResource()
         else:
             return self
 
@@ -84,9 +85,9 @@ class BaseTestRefUserResource(BaseTestWebAPIResource):
 
     def get_serializer_for_object(self, o):
         if isinstance(o, User):
-            return TestUserResource()
-        elif isinstance(o, TestGroup):
-            return TestGroupResource()
+            return MyTestUserResource()
+        elif isinstance(o, MyTestGroup):
+            return MyTestGroupResource()
         else:
             return self
 
@@ -360,15 +361,16 @@ class WebAPIResourceTests(TestModelsLoaderMixin, TestCase):
         resource = WebAPIResource()
         obj = TestObject()
 
-        with warnings.catch_warnings(record=True) as w:
-            warnings.simplefilter('always')
+        expected_message = (
+            'WebAPIResource.generate_etag is deprecated and no longer called '
+            'by default. Please provide your own ETag generation in '
+            'get_etag().'
+        )
+
+        with self.assertWarns(RemovedInDjblets30Warning, expected_message):
             etag = resource.generate_etag(obj, ['my_field'], request,
                                           encode_etag=True)
 
-        self.assertEqual(len(w), 1)
-        self.assertIn('generate_etag is deprecated',
-                      six.text_type(w[0].message))
-
         self.assertEqual(
             etag,
             encode_etag(
@@ -385,15 +387,16 @@ class WebAPIResourceTests(TestModelsLoaderMixin, TestCase):
         resource = WebAPIResource()
         obj = TestObject()
 
-        with warnings.catch_warnings(record=True) as w:
-            warnings.simplefilter('always')
+        expected_message = (
+            'WebAPIResource.generate_etag is deprecated and no longer called '
+            'by default. Please provide your own ETag generation in '
+            'get_etag().'
+        )
+
+        with self.assertWarns(RemovedInDjblets30Warning, expected_message):
             etag = resource.generate_etag(obj, None, request,
                                           encode_etag=False)
 
-        self.assertEqual(len(w), 1)
-        self.assertIn('generate_etag is deprecated',
-                      six.text_type(w[0].message))
-
         self.assertEqual(
             etag,
             repr(resource.serialize_object(obj, request=request)))
@@ -527,7 +530,7 @@ class WebAPIResourceTests(TestModelsLoaderMixin, TestCase):
             fields = {
                 'user': {
                     'type': ResourceFieldType,
-                    'resource': TestUserResource,
+                    'resource': MyTestUserResource,
                 },
             }
 
@@ -572,7 +575,7 @@ class WebAPIResourceTests(TestModelsLoaderMixin, TestCase):
             fields = {
                 'users': {
                     'type': ResourceListFieldType,
-                    'resource': TestUserResource,
+                    'resource': MyTestUserResource,
                 },
             }
 
@@ -635,7 +638,7 @@ class WebAPIResourceTests(TestModelsLoaderMixin, TestCase):
             users = User.objects.all()
 
         class TestResource(BaseTestRefUserResource):
-            item_child_resources = [TestUserResource()]
+            item_child_resources = [MyTestUserResource()]
 
             fields = {
                 'field': {
@@ -702,7 +705,7 @@ class WebAPIResourceTests(TestModelsLoaderMixin, TestCase):
         class TestObject(object):
             pk = '1'
             users = User.objects.all()
-            groups = TestGroup.objects.all()
+            groups = MyTestGroup.objects.all()
 
         class TestResource(BaseTestRefUserResource):
             item_child_resources = []
@@ -723,7 +726,7 @@ class WebAPIResourceTests(TestModelsLoaderMixin, TestCase):
                                     first_name='Test2',
                                     last_name='User2')
 
-        group = TestGroup.objects.create(name='group1')
+        group = MyTestGroup.objects.create(name='group1')
         group.users.add(user2)
 
         request = RequestFactory().get('/api/test/?expand=users,groups')
@@ -811,11 +814,11 @@ class WebAPIResourceTests(TestModelsLoaderMixin, TestCase):
                 },
                 'field2': {
                     'type': ResourceFieldType,
-                    'resource': TestUserResource,
+                    'resource': MyTestUserResource,
                 },
                 'field3': {
                     'type': ResourceFieldType,
-                    'resource': TestUserResource,
+                    'resource': MyTestUserResource,
                 },
             }
 
